@@ -12,7 +12,7 @@ class ReceiveMessageRequestTest extends TestCase
     {
         $input = new ReceiveMessageRequest([
             'QueueUrl' => 'queueUrl',
-            'AttributeNames' => [MessageSystemAttributeName::MESSAGE_GROUP_ID, MessageSystemAttributeName::MESSAGE_DEDUPLICATION_ID],
+            'MessageSystemAttributeNames' => [MessageSystemAttributeName::MESSAGE_GROUP_ID, MessageSystemAttributeName::MESSAGE_DEDUPLICATION_ID],
             'MessageAttributeNames' => ['Attribute1'],
             'MaxNumberOfMessages' => 5,
             'VisibilityTimeout' => 15,
@@ -25,10 +25,11 @@ class ReceiveMessageRequestTest extends TestCase
             POST / HTTP/1.0
             Content-Type: application/x-amz-json-1.0
             x-amz-target: AmazonSQS.ReceiveMessage
+            Accept: application/json
 
             {
                 "QueueUrl": "queueUrl",
-                "AttributeNames": ["MessageGroupId", "MessageDeduplicationId"],
+                "MessageSystemAttributeNames": ["MessageGroupId", "MessageDeduplicationId"],
                 "MessageAttributeNames": ["Attribute1"],
                 "MaxNumberOfMessages": 5,
                 "VisibilityTimeout": 15,
